@@ -101,7 +101,6 @@ class tentext:
         model.add(layers.Embedding(self.totalwords, 64,input_length=self.maxSequenceLen - 1))
         model.add(Dropout(dropout))
         model.add(layers.LSTM(lstmlayer))
-        model.add(layers.Dense(self.totalwords - 500, activation=activation))
         model.add(layers.Dense(self.totalwords, activation=activation))
         self.model = model
         print(self.model.summary())
@@ -126,7 +125,7 @@ class tentext:
         self.history = history
         return self.history
     
-    def predict(self, sample_text):               #A text seed is provided
+    def predict(self, sample_text, word_length):               #A text seed is provided
     
         '''Predicts the next text sequences'''
         #model = self.model    
